summaryrefslogtreecommitdiff
path: root/lisp/emacs-lisp/lisp-mnt.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/emacs-lisp/lisp-mnt.el')
-rw-r--r--lisp/emacs-lisp/lisp-mnt.el36
1 files changed, 18 insertions, 18 deletions
diff --git a/lisp/emacs-lisp/lisp-mnt.el b/lisp/emacs-lisp/lisp-mnt.el
index 62f47471404..f1df695fa5e 100644
--- a/lisp/emacs-lisp/lisp-mnt.el
+++ b/lisp/emacs-lisp/lisp-mnt.el
@@ -37,7 +37,8 @@
;; Another entry point automatically addresses bug mail to a package's
;; maintainer or author.
;; This file can be loaded by your lisp-mode-hook. Have it (require 'lisp-mnt)
;; This file is an example of the header conventions. Note the following
;; features:
@@ -305,12 +306,12 @@ If FILE is nil, execute BODY in the current buffer."
(if ,filesym
(with-temp-buffer
(insert-file-contents ,filesym)
- (lisp-mode)
+ (emacs-lisp-mode)
,@body)
(save-excursion
;; Switching major modes is too drastic, so just switch
- ;; temporarily to the Lisp mode syntax table.
- (with-syntax-table lisp-mode-syntax-table
+ ;; temporarily to the Emacs Lisp mode syntax table.
+ (with-syntax-table emacs-lisp-mode-syntax-table
,@body))))))
(put 'lm-with-file 'lisp-indent-function 1)
@@ -511,18 +512,17 @@ copyright notice is allowed."
(if (and file (file-directory-p file))
(setq ret
(with-temp-buffer
- (mapcar
- (lambda (f)
- (if (string-match ".*\\.el\\'" f)
- (let ((status (lm-verify f)))
- (insert f ":")
- (if status
- (lm-insert-at-column lm-comment-column status
- "\n")
- (if showok
- (lm-insert-at-column lm-comment-column
- "OK\n"))))))
- (directory-files file))))
+ (dolist (f (directory-files file nil "\\.el\\'")
+ (buffer-string))
+ (when (file-regular-p f)
+ (let ((status (lm-verify f)))
+ (insert f ":")
+ (if status
+ (lm-insert-at-column lm-comment-column status
+ "\n")
+ (if showok
+ (lm-insert-at-column lm-comment-column
+ "OK\n"))))))))
(lm-with-file file
(setq name (lm-get-package-name))
(setq ret
@@ -562,7 +562,7 @@ copyright notice is allowed."
(t
ret)))))
(if verbose
- (message ret))
+ (message "%s" ret))
ret))
(defun lm-synopsis (&optional file showall)
@@ -615,5 +615,5 @@ Prompts for bug subject TOPIC. Leaves you in a mail buffer."
(provide 'lisp-mnt)
-;;; arch-tag: fa3c5ab4-a37b-4e46-b7cf-b6d78b90e69e
+;; arch-tag: fa3c5ab4-a37b-4e46-b7cf-b6d78b90e69e
;;; lisp-mnt.el ends here
@@ -37,7 +37,8 @@
;; Another entry point automatically addresses bug mail to a package's
;; maintainer or author.
-;; This file can be loaded by your lisp-mode-hook. Have it (require 'lisp-mnt)
+;; This file can be loaded by your emacs-lisp-mode-hook. Have it
+;; (require 'lisp-mnt)
;; This file is an example of the header conventions. Note the following
;; features: